<?php

namespace Buyesrfolio\TransactionFiles\Providers;

use Illuminate\Support\ServiceProvider;

class TransactionFilesServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'transaction_files');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'transaction_files');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerTransactionFiles();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerTransactionFiles()
    {
        $this->app->bind('transaction_files', function($app) {
            return new TransactionFiles($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('TransactionFiles', 'Lavalite\TransactionFiles\Facades\TransactionFiles');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('buyesrfolio.transaction_files', function ($app) {
            return $this->app->make('Buyesrfolio\TransactionFiles\TransactionFiles');
        });

                // Bind TransactionFile to repository
        $this->app->bind(
            'Buyesrfolio\TransactionFiles\Interfaces\TransactionFileRepositoryInterface',
            \Buyesrfolio\TransactionFiles\Repositories\Eloquent\TransactionFileRepository::class
        );

        $this->app->register(\Buyesrfolio\TransactionFiles\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Buyesrfolio\TransactionFiles\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and transaction_files's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'buyesrfolio.transaction_files'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeTransactionFiles::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['buyesrfolio.transaction_files'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('buyesrfolio/transaction_files.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/transaction_files')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/transaction_files')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
